# pywash
A Python based data cleaning assistant for Machine Learning

Created as part of a Bachelor Final Project for the data mining group at the Technical University Eindhoven.

## Authors
* [Robin Kaelen](https://github.com/Robin66014)